==> document_to_podcast-1.1.1.tar.gz: document_to_podcast-1.1.1/docs/index.md <==
# **Document-to-Podcast Blueprint**

<div style="text-align: center;">
  <img src="images/document-to-podcast-diagram.png" alt="Project Logo" style="width: 100%; margin-bottom: 1px; margin-top: 1px;">
</div>

Blueprints empower developers to easily integrate AI capabilities into their projects using open-source models and tools.

These docs are your companion to mastering the **Document-to-Podcast Blueprint**—a local-first approach for transforming documents into engaging podcasts.

### Built with
- Python 3.10+
- [Llama-cpp](https://github.com/abetlen/llama-cpp-python) (text-to-text, i.e script generation)
- [OuteAI](https://github.com/edwko/OuteTTS) / [Parler_tts](https://github.com/huggingface/parler-tts) (text-to-speech, i.e audio generation)
- [Streamlit](https://streamlit.io/) (UI demo)


---

### 🚀 **Get Started Quickly**
#### _Start building your own Document-to-Podcast pipeline in minutes:_
- **[Getting Started](getting-started.md):** Quick setup and installation instructions.

### 🔍 **Understand the System**
#### _Dive deeper into how the Blueprint works:_
- **[Step-by-Step Guide](step-by-step-guide.md):** A detailed breakdown of the system’s design and workflow.
- **[API Reference](api.md):** Explore the technical details of the core modules.

### 🎨 **Make It Yours**
#### _Customize the Blueprint to fit your needs:_
- **[Customization Guide](customization.md):** Tailor prompts, voices, and settings to create unique podcasts.

### 🌟 **Join the Community**
#### _Help shape the future of Blueprints:_
- **[Future Features & Contributions](future-features-contributions.md):** Learn about exciting upcoming features and how to contribute to the project.


Have more questions? Reach out to us on Discord and we'll see how we can help:

---

## **Why Blueprints?**

Blueprints are more than starter code—they’re your gateway to building AI-powered solutions with confidence. With step-by-step guidance, modular design, and open-source tools, we make AI accessible for developers of all skill levels.

==> document_to_podcast-1.3.0.tar.gz: document_to_podcast-1.3.0/docs/index.md <==
# **Document-to-Podcast Blueprint**

<div style="text-align: center;">
  <img src="images/document-to-podcast-diagram.png" alt="Project Logo" style="width: 100%; margin-bottom: 1px; margin-top: 1px;">
</div>

Blueprints empower developers to easily integrate AI capabilities into their projects using open-source models and tools.

These docs are your companion to mastering the **Document-to-Podcast Blueprint**—a local-first approach for transforming documents into engaging podcasts.

### Built with
- Python 3.10+
- [Llama-cpp](https://github.com/abetlen/llama-cpp-python) (text-to-text, i.e script generation)
- [OuteAI](https://github.com/edwko/OuteTTS) (text-to-speech, i.e audio generation)
- [Streamlit](https://streamlit.io/) (UI demo)


---

### 🚀 **Get Started Quickly**
#### _Start building your own Document-to-Podcast pipeline in minutes:_
- **[Getting Started](getting-started.md):** Quick setup and installation instructions.

### 🔍 **Understand the System**
#### _Dive deeper into how the Blueprint works:_
- **[Step-by-Step Guide](step-by-step-guide.md):** A detailed breakdown of the system’s design and workflow.
- **[API Reference](api.md):** Explore the technical details of the core modules.

### 🎨 **Make It Yours**
#### _Customize the Blueprint to fit your needs:_
- **[Customization Guide](customization.md):** Tailor prompts, voices, and settings to create unique podcasts.

### 🌟 **Join the Community**
#### _Help shape the future of Blueprints:_
- **[Future Features & Contributions](future-features-contributions.md):** Learn about exciting upcoming features and how to contribute to the project.


Have more questions? Reach out to us on Discord and we'll see how we can help:

---

## **Why Blueprints?**

Blueprints are more than starter code—they’re your gateway to building AI-powered solutions with confidence. With step-by-step guidance, modular design, and open-source tools, we make AI accessible for developers of all skill levels.
